@@ -60,8 +60,8 @@ function parseProfile (data) {
 
   return {
     id: id || username,
-    username: username,
-    displayName: displayName,
+    username,
+    displayName,
     emails: email ? [email] : []
   }
 }
@@ -75,7 +75,13 @@ function checkAuthorization (data, done) {
       logger.error('oauth2: "accessRole" is configured, but "rolesClaim" is missing from the config. Can\'t check group membership!')
     } else {
       // parse and check role data
-      const roles = extractProfileAttribute(data, config.oauth2.rolesClaim)
+      let roles = []
+      try {
+        roles = extractProfileAttribute(data, config.oauth2.rolesClaim)
+      } catch (err) {
+        logger.warn(`oauth2: failed to extract rolesClaim '${config.oauth2.rolesClaim}' from user profile.`)
+        return done('Permission denied', null)
+      }
       if (!roles) {
         logger.error('oauth2: "accessRole" is configured, but user profile doesn\'t contain roles attribute. Permission denied')
         return done('Permission denied', null)
